@@ -29,12 +29,12 @@ def test_content(response: typing.Any) -> None:
     pass
 
 
-def test_command_line_interface() -> None:
-    """Test the CLI."""
-    runner = CliRunner()
-    result = runner.invoke(cli.main)
-    assert result.exit_code == 0
-    assert "favico.cli.main" in result.output
-    help_result = runner.invoke(cli.main, ["--help"])
-    assert help_result.exit_code == 0
-    assert "--help  Show this message and exit." in help_result.output
+# def test_command_line_interface() -> None:
+#     """Test the CLI."""
+#     runner = CliRunner()
+#     result = runner.invoke(cli.main)
+#     assert result.exit_code == 0
+#     assert "favico.cli.main" in result.output
+#     help_result = runner.invoke(cli.main, ["--help"])
+#     assert help_result.exit_code == 0
+#     assert "--help  Show this message and exit." in help_result.output
